<?php

namespace Litecms\Banner\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Litecms\Banner\Http\Requests\BannerRequest;
use Litecms\Banner\Models\Banner;

/**
 * Admin web controller class.
 */
class BannerWorkflowController extends BaseController
{

    /**
     * Workflow controller function for banner.
     *
     * @param Model   $banner
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(BannerRequest $request, Banner $banner, $step)
    {

        try {

            $banner->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('banner::banner.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/banner/banner/' . $banner->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/banner/banner/' . $banner->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for banner.
     *
     * @param Model   $banner
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Banner $banner, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $banner->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('banner::banner.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('banner::admin.banner.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('banner::admin.banner.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('banner::admin.banner.message', $data)->render();

        }

    }
}
