<?php

namespace Litecms\Banner\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Banner\Models\Banner;

class BannerPolicy
{

    /**
     * Determine if the given user can view the banner.
     *
     * @param UserPolicy $user
     * @param Banner $banner
     *
     * @return bool
     */
    public function view(UserPolicy $user, Banner $banner)
    {
        if ($user->canDo('banner.banner.view') && $user->isAdmin()) {
            return true;
        }

        return $banner->user_id == user_id() && $banner->user_type == user_type();
    }

    /**
     * Determine if the given user can create a banner.
     *
     * @param UserPolicy $user
     * @param Banner $banner
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('banner.banner.create');
    }

    /**
     * Determine if the given user can update the given banner.
     *
     * @param UserPolicy $user
     * @param Banner $banner
     *
     * @return bool
     */
    public function update(UserPolicy $user, Banner $banner)
    {
        if ($user->canDo('banner.banner.edit') && $user->isAdmin()) {
            return true;
        }

        return $banner->user_id == user_id() && $banner->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given banner.
     *
     * @param UserPolicy $user
     * @param Banner $banner
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Banner $banner)
    {
        return $banner->user_id == user_id() && $banner->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given banner.
     *
     * @param UserPolicy $user
     * @param Banner $banner
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Banner $banner)
    {
        if ($user->canDo('banner.banner.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given banner.
     *
     * @param UserPolicy $user
     * @param Banner $banner
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Banner $banner)
    {
        if ($user->canDo('banner.banner.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
