<?php

namespace Litecms\Banner\Providers;

use Illuminate\Support\ServiceProvider;

class BannerServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'banner');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'banner');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.banner', function ($app) {
            return $this->app->make('Litecms\Banner\Banner');
        });

                // Bind Banner to repository
        $this->app->bind(
            'Litecms\Banner\Interfaces\BannerRepositoryInterface',
            \Litecms\Banner\Repositories\Eloquent\BannerRepository::class
        );

        $this->app->register(\Litecms\Banner\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\Banner\Providers\RouteServiceProvider::class);
                $this->app->register(\Litecms\Banner\Providers\WorkflowServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.banner'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/banner.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/banner')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/banner')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
