<?php

namespace Litecms\Banner\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Litecms\Banner\Models\Banner;

class BannerAction
{
    /**
     * Perform the complete action.
     *
     * @param Banner $banner
     *
     * @return Banner
     */
    public function complete(Banner $banner)
    {
        try {
            $banner->status = 'complete';
            return $banner->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Banner $banner
     *
     * @return Banner
     */public function verify(Banner $banner)
    {
        try {
            $banner->status = 'verify';
            return $banner->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Banner $banner
     *
     * @return Banner
     */public function approve(Banner $banner)
    {
        try {
            $banner->status = 'approve';
            return $banner->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Banner $banner
     *
     * @return Banner
     */public function publish(Banner $banner)
    {
        try {
            $banner->status = 'publish';
            return $banner->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Banner $banner
     *
     * @return Banner
     */
    public function archive(Banner $banner)
    {
        try {
            $banner->status = 'archive';
            return $banner->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Banner $banner
     *
     * @return Banner
     */
    public function unpublish(Banner $banner)
    {
        try {
            $banner->status = 'unpublish';
            return $banner->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
