<?php

namespace Litecms\Banner\Workflow;

use Litecms\Banner\Models\Banner;
use Validator;

class BannerValidator
{

    /**
     * Determine if the given banner is valid for complete status.
     *
     * @param Banner $banner
     *
     * @return bool / Validator
     */
    public function complete(Banner $banner)
    {
        return Validator::make($banner->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given banner is valid for verify status.
     *
     * @param Banner $banner
     *
     * @return bool / Validator
     */
    public function verify(Banner $banner)
    {
        return Validator::make($banner->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given banner is valid for approve status.
     *
     * @param Banner $banner
     *
     * @return bool / Validator
     */
    public function approve(Banner $banner)
    {
        return Validator::make($banner->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given banner is valid for publish status.
     *
     * @param Banner $banner
     *
     * @return bool / Validator
     */
    public function publish(Banner $banner)
    {
        return Validator::make($banner->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given banner is valid for archive status.
     *
     * @param Banner $banner
     *
     * @return bool / Validator
     */
    public function archive(Banner $banner)
    {
        return Validator::make($banner->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given banner is valid for unpublish status.
     *
     * @param Banner $banner
     *
     * @return bool / Validator
     */
    public function unpublish(Banner $banner)
    {
        return Validator::make($banner->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
